@@ -95,12 +95,15 @@ class Hexaboard():
             self.rocs[roc].configure(configuration[roc],
                                      readback=readback)
 
-    def read(self, configuration):
+    def read(self, configuration, from_hardware):
         """
         Read the current configuration parameters from cache
 
         :param configuration: Parameters to read from cache
         :type configuration: dict
+        :param from_hardware: Set to read directly from registers and
+            skip the cache
+        :type from_hardware: bool
         :return: Values of parameters read from cache
         :rtype: dict
         """
@@ -108,7 +111,8 @@ class Hexaboard():
         for roc_name in self.rocs.keys():
             if roc_name in configuration:
                 recv[roc_name] = \
-                    self.rocs[roc_name].read(configuration[roc_name])
+                    self.rocs[roc_name].read(
+                            configuration[roc_name], from_hardware)
         return recv
 
     def reset(self):
