@@ -10,6 +10,7 @@ from .Hexaboard import Hexaboard
 cmd_schema_recv = Schema({'type':
                           Or('set', 'get', 'describe', 'reset', 'stop'),
                           Optional('read_back', default=False): bool,
+                          Optional('from_hardware', default=False): bool,
                           'status': 'send',
                           'args': dict})
 
@@ -58,7 +59,8 @@ class Server():
                         case 'get':
                             try:
                                 response_args = self.hexaboard.read(
-                                        client_request['args'])
+                                        client_request['args'],
+                                        client_request['from_hardware'])
                                 self._respond('get', response_args)
                             except (KeyError, ValueError, IOError) as error:
                                 self._respond('get', error=error.args[0])
